@@ -19,6 +19,7 @@ actions:
   -d, --dot             print dependency graph in dot (graphviz) format
   -n, --names           print dependency graph with all imported names
   -u, --unused          print unused imports
+  -C, --csv             print imports and module name in a CSV table
 
 options:
   -a, --all             don't ignore unused imports when there's a comment on
@@ -38,6 +39,8 @@ options:
   -c, --collapse        collapse dependency cycles
   -T, --tests           collapse packages named 'tests' and 'ftests' with
                         parent packages
+  -s MODULE, --search-import MODULE
+                        only show imports matching module or package name
   -w FILE, --write-cache FILE
                         write a pickle cache of parsed imports; provide the
                         cache filename as the only non-option argument to load
@@ -108,7 +111,7 @@ import zipfile
 from operator import attrgetter
 
 
-__version__ = '2.5.2'
+__version__ = '2.6.0'
 __author__ = 'Marius Gedminas <marius@gedmin.as>'
 __licence__ = 'MIT'
 __url__ = 'https://github.com/mgedmin/findimports'
@@ -571,7 +574,8 @@ class ModuleGraph(object):
         print(message, file=self._stderr)
         self._warned_about.add(about)
 
-    def parsePathname(self, pathname, ignores=[], ignore_stdlib_modules=False):
+    def parsePathname(self, pathname, ignores=[], ignore_stdlib_modules=False,
+                      import_to_search_for=None):
         """Parse one or more source files.
 
         ``pathname`` may be a file name or a directory name.
@@ -588,11 +592,13 @@ class ModuleGraph(object):
                     # ignore emacsish junk
                     if fn.endswith('.py') and not fn.startswith('.#'):
                         self.parseFile(os.path.join(root, fn),
-                                       ignore_stdlib_modules)
+                                       ignore_stdlib_modules,
+                                       import_to_search_for)
         elif pathname.endswith('.importcache'):
             self.readCache(pathname)
         else:
-            self.parseFile(pathname, ignore_stdlib_modules)
+            self.parseFile(
+                pathname, ignore_stdlib_modules, import_to_search_for)
 
     def filterIgnores(self, dirs, files, ignores):
         for ignore in ignores:
@@ -611,7 +617,7 @@ class ModuleGraph(object):
         with open(filename, 'rb') as f:
             self.modules = pickle.load(f)
 
-    def parseFile(self, filename, ignore_stdlib_modules):
+    def parseFile(self, filename, ignore_stdlib_modules, import_to_search_for):
         """Parse a single file."""
         modname = self.filenameToModname(filename)
         module = Module(modname, filename)
@@ -633,6 +639,11 @@ class ModuleGraph(object):
                 info for info in module.imported_names
                 if info.name.split('.')[0] not in STDLIB_MODNAMES_SET
             ]
+        if import_to_search_for:
+            module.imported_names = [
+                info for info in module.imported_names
+                if import_to_search_for in info.name
+            ]
         module.imports = {
             self.findModuleOfName(
                 imp.name, imp.level, filename, lineno=imp.lineno, extrapath=dir
@@ -953,6 +964,12 @@ class ModuleGraph(object):
             print("  " + "\n  ".join(
                 imp.name for imp in module.imported_names))
 
+    def printCsv(self):
+        """Produce a report in csv format."""
+        for module in self.listModules():
+            for imp in module.imported_names:
+                print(f"{module.modname},{imp.name}")
+
     def printImports(self):
         """Produce a report of dependencies."""
         for module in self.listModules():
@@ -1055,6 +1072,9 @@ def main(argv=None):
     actions.add_argument('-u', '--unused', action='store_const',
                          dest='action', const='printUnusedImports',
                          help='print unused imports')
+    actions.add_argument('-C', '--csv', action='store_const',
+                         dest='action', const='printCsv',
+                         help='print imports and module name in a CSV table')
 
     options = parser.add_argument_group('options')
     options.add_argument('-a', '--all', action='store_true',
@@ -1091,6 +1111,10 @@ def main(argv=None):
                          dest='collapse_tests',
                          help="collapse packages named 'tests' and 'ftests'"
                               " with parent packages")
+    options.add_argument('-s', '--search-import', metavar='MODULE',
+                         dest='import_to_search_for',
+                         help="only show imports matching module or package "
+                              "name")
     options.add_argument('-w', '--write-cache', metavar='FILE',
                          help="write a pickle cache of parsed imports; provide"
                               " the cache filename as the only non-option"
@@ -1125,7 +1149,8 @@ def main(argv=None):
     for fn in args.filenames:
         g.parsePathname(fn,
                         ignores=args.ignore or ["venv"],
-                        ignore_stdlib_modules=args.ignore_stdlib)
+                        ignore_stdlib_modules=args.ignore_stdlib,
+                        import_to_search_for=args.import_to_search_for)
     if args.write_cache:
         g.writeCache(args.write_cache)
 
